# enable_gtkdoc: Toggle if gtk-doc files should be rebuilt.
#      0 = no
#      1 = yes
%define enable_gtkdoc 1

# enable_bootstrap: Toggle if bootstrapping package
#      0 = no
#      1 = yes
# N.B. when disabling bootstrap, toggle enable_gtkdoc to 1, otherwise the build
# fails as autoreconf -fi exits with 1
%define enable_bootstrap 0

# enable_tests: Run test suite in build
#      0 = no
#      1 = yes
%define enable_tests 0

%{?_without_gtkdoc: %{expand: %%define enable_gtkdoc 0}}
%{?_without_bootstrap: %{expand: %%define enable_bootstrap 0}}
%{?_without_tests: %{expand: %%define enable_tests 0}}

%{?_with_gtkdoc: %{expand: %%define enable_gtkdoc 1}}
%{?_with_bootstrap: %{expand: %%define enable_bootstrap 1}}
%{?_with_tests: %{expand: %%define enable_tests 1}}


# required version of various libraries
%define req_glib_version		2.27.3
%define req_pango_version		1.20.0
%define req_atk_version			1.29.4
%define req_cairo_version		1.6.0
%define req_gdk_pixbuf_version		2.21.0

%define pkgname			gtk+
%define api_version		2.0
%define binary_version		2.10.0
%define lib_major		0
%define libname			%mklibname %{pkgname} %{api_version} %{lib_major}
%define libname_x11		%mklibname %{pkgname}-x11- %{api_version} %{lib_major}
%define develname		%mklibname -d %pkgname %api_version

%define gail_major 18
%define gail_libname %mklibname gail %gail_major
%define gaildevelname %mklibname -d gail

%define git_url git://git.gnome.org/gtk+

%define major_url	%(echo %{version}|cut -d. -f1,2)

%define gi_major	2.0
%define girname		%mklibname gtk-gir %gi_major

Summary:	The GIMP ToolKit (GTK+), a library for creating GUIs
Name:		%{pkgname}%{api_version}
Version:	2.24.26
Release:	%mkrel 3
License:	LGPLv2+
Group:		System/Libraries
Source0:	https://download.gnome.org/sources/%{pkgname}/%{major_url}/%{pkgname}-%{version}.tar.xz
# extra IM modules (vietnamese and tamil) -- pablo
#gw TODO, needs to be fixed for 2.21.3
Patch4:		gtk+-2.13.1-extra_im.patch 
# (fc) 2.0.6-8mdk fix infinite loop and crash in file selector when / and $HOME are not readable (bug #90)
Patch5:		gtk+-2.6.9-fileselectorfallback.patch
# (gb) 2.4.4-2mdk handle biarch
Patch13:	gtk+-2.2.4-lib64.patch
# (fc) 2.20.0-2mdv allow window dragging toolbars / menubar (GNOME bug #611313)
Patch20:	gtk+-2.24.7-window-dragging.patch
# (fc) 2.20.0-3mdv allow specifying icon padding for tray icon (GNOME bug #583273) (Fedora)
Patch21:	gtk+-2.20.0-icon-padding.patch
Patch22:	gtk+-2.24.9-link-gmodule.patch
# (wally) fallback to Adwaita icon theme
Patch23:	gtk+-2.24.25-fallback-to-Adwaita-icon-theme.patch
# (lm) reverting "Make gdk_event_apply_filters safe against changes in filter list"
# (commit ee95f3d7259c0859ce41189b781b4339b4cd64aa) could fix mga#15375
Patch24:	gtk+-2.24.26-Revert-Make-gdk_event_apply_filters-safe.patch
# Fix integer overflow: CVE-2013-7447 and mga#17731
Patch25:	gtk+-2.24.26-avoid-integer-overflow.patch
# (fedora/upstream) ignore gdk-pixbuf deprecations
Conflicts:	perl-Gtk2 < 1.113

URL:		http://www.gtk.org
Requires:	common-licenses
BuildRequires:	gettext-devel
BuildRequires:  libglib2.0-devel >= %{req_glib_version}
BuildRequires:	pkgconfig(atk) >= %{req_atk_version}
BuildRequires:  pkgconfig(cairo) >= %{req_cairo_version}
BuildRequires:	pkgconfig(pango) >= %{req_pango_version}
BuildRequires:  gobject-introspection-devel >= 0.9.5
BuildRequires:	libgdk_pixbuf2.0-devel >= %req_gdk_pixbuf_version
BuildRequires:	pkgconfig(x11)
BuildRequires:	pkgconfig(xext)
BuildRequires:	pkgconfig(xinerama)
BuildRequires:	pkgconfig(xi)
BuildRequires:	pkgconfig(xrender)
BuildRequires:	pkgconfig(xrandr)
BuildRequires:	pkgconfig(xcomposite)
BuildRequires:	pkgconfig(xdamage)
BuildRequires:	pkgconfig(xfixes)
BuildRequires:	pkgconfig(xcursor)
BuildRequires:  cups-devel
BuildRequires:  pkgconfig(gamin)
%if %enable_tests
BuildRequires:  x11-server-xvfb
%endif
%if %enable_gtkdoc
BuildRequires: gtk-doc >= 0.9 
BuildRequires: sgml-tools
BuildRequires: texinfo
%endif
# gw tests will fail without this
BuildRequires: fonts-ttf-dejavu
# so that the demos don't fail to build
BuildRequires: shared-mime-info
%if !%{enable_bootstrap}
Requires: xdg-user-dirs-gtk
%endif
Recommends:       %mklibname gvfs 0
Requires: %{libname} = %{version}
Provides:	%{pkgname}2 = %{version}-%{release}
Obsoletes:	%{pkgname}2
Provides:	gail = %version-%release
Obsoletes:	gail

%description
The gtk+ package contains the GIMP ToolKit (GTK+), a library for creating
graphical user interfaces for the X Window System.  GTK+ was originally
written for the GIMP (GNU Image Manipulation Program) image processing
program, but is now used by several other programs as well.  

If you are planning on using the GIMP or another program that uses GTK+,
you'll need to have the gtk+ package installed.


%post
if [ -d %{_datadir}/icons ]; then
 for i in `/bin/ls %{_datadir}/icons` ; do
  [ -d "%{_datadir}/icons/$i" -a -e "%{_datadir}/icons/$i/icon-theme.cache" -a -e "%{_datadir}/icons/$i/index.theme" ] && gtk-update-icon-cache --force --quiet %{_datadir}/icons/$i
 done
 exit 0
fi

%files -f gtk20.lang
%doc README
%{_bindir}/gtk-query-immodules-%{api_version}
%{_bindir}/gtk-update-icon-cache
%{_datadir}/themes
%dir %{_sysconfdir}/gtk-%{api_version}
%config(noreplace) %{_sysconfdir}/gtk-%{api_version}/im-multipress.conf

#--------------------------------------------------------------------

%package -n %{libname}
Summary: %{summary}
Group:	 %{group}
Obsoletes:	lib%{pkgname}2
Provides:	lib%{pkgname}2 = %{version}-%{release}
Provides:	lib%{name} = %{version}-%{release}
Provides:	gtk2 = %{version}-%{release}
Requires:	libglib2.0 >= %{req_glib_version}
Requires:	libpango1.0 >= %{req_pango_version}
Requires:	glib2.0-common
Requires(post):	%{libname_x11} = %{version}
# required for icon theme apis to work
Requires:	hicolor-icon-theme


%description -n %{libname}
This package contains the library needed to run programs dynamically
linked with gtk+.

%post -n %{libname}
if [ "$1" = "2" ]; then
  if [ -f %{_sysconfdir}/gtk-%{api_version}/gtk.immodules ]; then
    rm -f %{_sysconfdir}/gtk-%{api_version}/gtk.immodules
  fi
fi

%{_libdir}/gtk-%{api_version}/bin/gtk-query-immodules-%{api_version} --update-cache

%files -n %{libname}
%doc README
%ghost %verify (not md5 mtime size) %_libdir/gtk-%{api_version}/%{binary_version}/immodules.cache
%dir %{_libdir}/gtk-%{api_version}
%dir %{_libdir}/gtk-%{api_version}/bin
%{_libdir}/gtk-%{api_version}/bin/gtk-query-immodules-%{api_version}
%dir %{_libdir}/gtk-%{api_version}/modules
%dir %{_libdir}/gtk-%{api_version}/%{binary_version}
%dir %{_libdir}/gtk-%{api_version}/%{binary_version}/immodules
%{_libdir}/gtk-%{api_version}/%{binary_version}/immodules/im-am-et.so
%{_libdir}/gtk-%{api_version}/%{binary_version}/immodules/im-cedilla.so
%{_libdir}/gtk-%{api_version}/%{binary_version}/immodules/im-cyrillic-translit.so
%{_libdir}/gtk-%{api_version}/%{binary_version}/immodules/im-inuktitut.so
%{_libdir}/gtk-%{api_version}/%{binary_version}/immodules/im-ipa.so
%{_libdir}/gtk-%{api_version}/%{binary_version}/immodules/im-multipress.so
%{_libdir}/gtk-%{api_version}/%{binary_version}/immodules/im-thai.so
%{_libdir}/gtk-%{api_version}/%{binary_version}/immodules/im-ti-er.so
%{_libdir}/gtk-%{api_version}/%{binary_version}/immodules/im-ti-et.so
%{_libdir}/gtk-%{api_version}/%{binary_version}/immodules/im-viqr.so
%{_libdir}/gtk-%{api_version}/%{binary_version}/immodules/im-xim.so
%{_libdir}/gtk-%{api_version}/%{binary_version}/immodules/im-tamilvp-tsc.so
%{_libdir}/gtk-%{api_version}/%{binary_version}/immodules/im-tamilvp-uni.so
%{_libdir}/gtk-%{api_version}/%{binary_version}/immodules/im-telex.so
%{_libdir}/gtk-%{api_version}/%{binary_version}/immodules/im-vni.so
%dir %{_libdir}/gtk-%{api_version}/%{binary_version}/engines
%{_libdir}/gtk-%{api_version}/%{binary_version}/engines/*.so
%{_libdir}/gtk-%{api_version}/%{binary_version}/printbackends/*.so
%{_var}/lib/rpm/filetriggers/gtk-query-immodules-%{api_version}-%{__isa_bits}.*

#--------------------------------------------------------------------

%package -n %{develname}
Summary:	Development files for GTK+ (GIMP ToolKit) applications
Group:		Development/GNOME and GTK+
Obsoletes:  %{libname_x11}-devel
Provides:   %{libname_x11}-devel = %{version}-%{release}
Provides:   gtk2-devel = %{version}-%{release}
Obsoletes:	%{pkgname}2-devel
Obsoletes:  lib%{pkgname}2-devel
Obsoletes:  %mklibname -d %{pkgname} 2.0 0
Provides:	%{pkgname}2-devel = %{version}-%{release}
Provides:	lib%{pkgname}2-devel = %{version}-%{release}
Provides:	lib%{pkgname}%{api_version}-devel = %{version}-%{release}
Provides:	%{libname}-devel = %{version}-%{release}
Provides:	lib%{pkgname}-x11-%{api_version}-devel = %{version}-%{release}
Requires:	%{libname} = %{version}
Requires:	%{libname_x11} = %{version}
Requires:	libgdk_pixbuf2.0-devel >= %req_gdk_pixbuf_version
Requires:	libatk1.0-devel >= %{req_atk_version}
Requires:	libpango1.0-devel >= %{req_pango_version}


%description -n %{develname}
The libgtk+-devel package contains the static libraries and header files
needed for developing GTK+ (GIMP ToolKit) applications. The libgtk+-devel
package contains GDK (the General Drawing Kit, which simplifies the interface
for writing GTK+ widgets and using GTK+ widgets in applications), and GTK+
(the widget set).

%files -n %develname
%doc docs/*.txt AUTHORS ChangeLog NEWS README*
%doc %{_datadir}/gtk-doc/html/gdk2
%doc %{_datadir}/gtk-doc/html/gtk2
%{_bindir}/gtk-demo
%_bindir/gtk-builder-convert
%{_datadir}/aclocal/*
%{_datadir}/gtk-%{api_version}
%{_includedir}/gtk-unix-print-%{api_version}/
%{_includedir}/gtk-%{api_version}/gdk
%{_includedir}/gtk-%{api_version}/gtk
%{_libdir}/gtk-%{api_version}/include
%{_libdir}/pkgconfig/gdk-%{api_version}.pc
%{_libdir}/pkgconfig/gtk+-%{api_version}.pc
%{_libdir}/pkgconfig/gtk+-unix-print-%{api_version}.pc
%{_libdir}/*x11*.so
%_datadir/gir-1.0/Gdk-2.0.gir
%_datadir/gir-1.0/GdkX11-2.0.gir
%_datadir/gir-1.0/Gtk-2.0.gir
%{_libdir}/pkgconfig/*x11*

#--------------------------------------------------------------------

%package -n %{libname_x11}
Summary:	X11 backend of The GIMP ToolKit (GTK+)
Group:		System/Libraries
Provides:	lib%{pkgname}-x11-%{api_version} = %{version}-%{release}
Provides:	%{name}-backend = %{version}-%{release}
Requires: 	%{libname} = %{version}
Requires:	%{name} >= %{version}-%{release}
Requires:	libatk1.0 >= %{req_atk_version}
Requires:	%{mklibname xi 6} >= 1.4.5
Requires:	%{mklibname x11_ 6} >= 1.4.99.1
Conflicts: gir-repository < 0.6.5-4

%description -n %{libname_x11}
This package contains the X11 version of library needed to run
programs dynamically linked with gtk+.

%files -n %{libname_x11}
%{_libdir}/libgdk-x11-%{api_version}.so.%{lib_major}
%{_libdir}/libgdk-x11-%{api_version}.so.%{lib_major}.*
%{_libdir}/libgtk-x11-%{api_version}.so.%{lib_major}
%{_libdir}/libgtk-x11-%{api_version}.so.%{lib_major}.*

#--------------------------------------------------------------------

%package -n %{gail_libname}
Summary:	GNOME Accessibility Implementation Library
Group:		System/Libraries
Provides:	libgail = %{version}-%{release}

%description -n %{gail_libname}
Gail is the GNOME Accessibility Implementation Library

%files -n %gail_libname
%{_libdir}/libgailutil.so.%{gail_major}*
%{_libdir}/gtk-2.0/modules/libferret.so
%{_libdir}/gtk-2.0/modules/libgail.so

#--------------------------------------------------------------------

%package -n %gaildevelname
Summary:	Static libraries, include files for GAIL
Group:		Development/GNOME and GTK+
Provides:	gail-devel = %{version}-%{release}
Provides:	libgail-devel = %{version}-%{release}
Requires:	%{gail_libname} = %{version}
Conflicts:	%{_lib}gail17-devel
Obsoletes: %mklibname -d gail 18

%description -n %gaildevelname
Gail is the GNOME Accessibility Implementation Library

%files -n %gaildevelname
%{_datadir}/gtk-doc/html/gail-libgail-util
%{_libdir}/libgailutil.so
%{_includedir}/gail-1.0
%{_libdir}/pkgconfig/gail.pc

#--------------------------------------------------------------------

%package -n %{girname}
Summary:        GObject Introspection interface description for %name
Group:          System/Libraries
Requires:	%{libname} = %{version}-%{release}
Requires:	%{libname_x11} = %{version}-%{release}
Conflicts:	%{mklibname %{name}-gir 2.0} < 2.24.5-5
Conflicts:	%{mklibname %{pkgname}-x11- 2.0 0} < 2.24.5-3

%description -n %{girname}
GObject Introspection interface description for %name.

%files -n %{girname}
%_libdir/girepository-1.0/Gdk-%{gi_major}.typelib
%_libdir/girepository-1.0/GdkX11-%{gi_major}.typelib
%_libdir/girepository-1.0/Gtk-%{gi_major}.typelib

#--------------------------------------------------------------------

%prep
%setup -n %{pkgname}-%{version} -q
%apply_patches

%if %{enable_bootstrap}
#gw disabled for bootstrapping
%patch13 -p1 -R
%endif

%build
# generate build scripts with our autotools
mkdir -p m4
autoreconf -fi

%ifarch ppc64
export CFLAGS="$RPM_OPT_FLAGS -mminimal-toc"
%endif

# Build X11 backend
#[ -d X11-build ] || mkdir X11-build
#cd X11-build

# fix crash in nautilus (GNOME bug #596977)
export CFLAGS=`echo $RPM_OPT_FLAGS | sed -e 's/-fomit-frame-pointer//g'`

#CONFIGURE_TOP=.. 
export CPPFLAGS="-DGTK_COMPILATION"
#	--with-included-immodules=yes \
%configure2_5x --enable-xinerama \
	--with-xinput=xfree \
%if !%enable_gtkdoc
	--enable-gtk-doc=no
%endif

%make

%check
%if %enable_tests
#cd X11-build
XDISPLAY=$(i=1; while [ -f /tmp/.X$i-lock ]; do i=$(($i+1)); done; echo $i)
%{_bindir}/Xvfb :$XDISPLAY &
export DISPLAY=:$XDISPLAY
make check
kill $(cat /tmp/.X$XDISPLAY-lock) ||:
#cd ..
%endif

%install
#cd X11-build
%makeinstall_std mandir=%{_mandir} RUN_QUERY_IMMODULES_TEST=false RUN_QUERY_LOADER_TEST=false


#cd ..

mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/gtk-%{api_version}
mkdir -p $RPM_BUILD_ROOT%{_libdir}/gtk-%{api_version}/modules

# Handle biarch packages
progs="gtk-query-immodules-%{api_version}"
mkdir -p $RPM_BUILD_ROOT%{_libdir}/gtk-%{api_version}/bin
for prog in $progs; do
  mv -f $RPM_BUILD_ROOT%{_bindir}/$prog $RPM_BUILD_ROOT%{_libdir}/gtk-%{api_version}/bin/
  cat >$RPM_BUILD_ROOT%{_bindir}/$prog <<EOF
#!/bin/sh
EC64=0
if [ -x %{_prefix}/lib64/gtk-%{api_version}/bin/$prog ]; then
  %{_prefix}/lib64/gtk-%{api_version}/bin/$prog "\$@"
  EC64=\$?
fi
EC32=0
if [ -x %{_prefix}/lib/gtk-%{api_version}bin/$prog ]; then
  %{_prefix}/lib/gtk-%{api_version}bin/$prog "\$@"
  EC32=\$?
fi
if [ "\$EC64" = "0" ]; then
  exit \$EC32
fi
exit \$EC64
EOF
  chmod 0755 $RPM_BUILD_ROOT%{_bindir}/$prog
done

# Automatic immodule cache compilation on rpm installs/removals 
touch $RPM_BUILD_ROOT%_libdir/gtk-%{api_version}/%{binary_version}/immodules.cache
mkdir -p $RPM_BUILD_ROOT%{_var}/lib/rpm/filetriggers 
cat >$RPM_BUILD_ROOT%{_var}/lib/rpm/filetriggers/gtk-query-immodules-%{api_version}-%{__isa_bits}.filter <<EOF
^.%{_libdir}/gtk-%{api_version}/.*immodules/.*\\.so\$
EOF
cat >$RPM_BUILD_ROOT%{_var}/lib/rpm/filetriggers/gtk-query-immodules-%{api_version}-%{__isa_bits}.script <<EOF
#!/bin/sh
%{_libdir}/gtk-%{api_version}/bin/gtk-query-immodules-%{api_version} --update-cache
EOF
chmod 0755 $RPM_BUILD_ROOT%{_var}/lib/rpm/filetriggers/gtk-query-immodules-%{api_version}-%{__isa_bits}.script

%{find_lang} gtk20
%find_lang gtk20-properties
cat gtk20-properties.lang >> gtk20.lang

#remove not packaged files
find %{buildroot} -name '*.la' -delete


%changelog
* Thu Feb 11 2016 tarakbumba <tarakbumba> 2.24.26-3.mga5
+ Revision: 955918
- Fix integer overflow: CVE-2013-7447 and mga#17731

* Fri Apr 17 2015 tmb <tmb> 2.24.26-3.mga5
+ Revision: 820386
- rebuild for missing debug packages

* Mon Mar 02 2015 lmenut <lmenut> 2.24.26-2.mga5
+ Revision: 817290
- try to revert commit 'Make gdk_event_apply_filters safe against changes in
  filter list' to fix drakconf closing (mga#15375)

* Mon Feb 16 2015 ovitters <ovitters> 2.24.26-1.mga5
+ Revision: 815275
- new version 2.24.26
- dropped merged patch 8

* Thu Feb 05 2015 ovitters <ovitters> 2.24.25-4.mga5
+ Revision: 813545
- add patch to fix build with new gdk-pixbuf
- don't force Oxygen like gtk+3.0 package

* Fri Oct 24 2014 wally <wally> 2.24.25-3.mga5
+ Revision: 793005
- add patch to hardcode fallback icon theme to Adwaita

* Wed Oct 15 2014 umeabot <umeabot> 2.24.25-2.mga5
+ Revision: 749138
- Second Mageia 5 Mass Rebuild

* Sat Oct 11 2014 ovitters <ovitters> 2.24.25-1.mga5
+ Revision: 738006
- new version 2.24.25

* Fri Sep 26 2014 wally <wally> 2.24.24-5.mga5
+ Revision: 724898
- rebuild with new rpm-mageia-setup to generate requires for .typelib files

* Tue Sep 16 2014 umeabot <umeabot> 2.24.24-4.mga5
+ Revision: 679997
- Mageia 5 Mass Rebuild

  + tv <tv>
    - s/uggests:/Recommends:/

* Sun Jul 20 2014 colin <colin> 2.24.24-3.mga5
+ Revision: 654829
- Fix immodules rpm filetrigger filter regex

* Sun Jul 20 2014 colin <colin> 2.24.24-2.mga5
+ Revision: 654789
- Drop the /etc/gtk-2.0/gtk.immodules.* files (no longer used)
- Make binary version explicit
- Ghost immodules.cache file
- Add immodule handling filetrigger
- Make immodule wrapper script run all arches it can find (which is
  probably what a user running manually would expect)

  + ovitters <ovitters>
    - new version 2.24.24
    - new version 2.24.23

  + yochenhsieh <yochenhsieh>
    - fix build error.
    - Alter gtk-query-immodules-2.0 command to fix bug 8731.

* Mon Jan 06 2014 tv <tv> 2.24.22-3.mga4
+ Revision: 565178
- move the suggests on gvfs from glib here (debloat, mga#8455)

* Mon Oct 21 2013 umeabot <umeabot> 2.24.22-2.mga4
+ Revision: 541164
- Mageia 4 Mass Rebuild

* Fri Oct 11 2013 ovitters <ovitters> 2.24.22-1.mga4
+ Revision: 495249
- new version 2.24.22

* Sat Sep 28 2013 lmenut <lmenut> 2.24.21-2.mga4
+ Revision: 488579
- rebuild with fixed rpm (missing suggests tags)

* Tue Sep 17 2013 tv <tv> 2.24.21-1.mga4
+ Revision: 480910
- new release

* Sat Sep 14 2013 wally <wally> 2.24.20-3.mga4
+ Revision: 478924
- enable xdg-user-dirs-gtk require again as gtk3 is rebuild with new colord

* Sat Sep 14 2013 wally <wally> 2.24.20-2.mga4
+ Revision: 478837
- temporarily disable xdg-user-dirs-gtk dep

* Fri Jul 12 2013 tv <tv> 2.24.20-1.mga4
+ Revision: 453283
- new release
- lib64 patch: drop unmergable bit

* Sun Jun 16 2013 ovitters <ovitters> 2.24.19-1.mga4
+ Revision: 443735
- new version 2.24.19

* Thu May 23 2013 tv <tv> 2.24.18-1.mga4
+ Revision: 425327
- new release

* Sun Apr 07 2013 wally <wally> 2.24.17-1.mga3
+ Revision: 408832
- new version 2.24.17

  + tv <tv>
    - do not package useless gtk+-0.99 NEWS

* Thu Feb 21 2013 wally <wally> 2.24.16-1.mga3
+ Revision: 399645
- new version 2.24.16
- drop unneeded automake 1.13 patch

* Sat Jan 12 2013 umeabot <umeabot> 2.24.14-2.mga3
+ Revision: 352800
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sat Jan 05 2013 cjw <cjw> 2.24.14-1.mga3
+ Revision: 338849
- fix filelist for changed gtk-doc dir names
- fix automake 1.13 patch to remove AM_PROG_CC_STDC

  + dmorgan <dmorgan>
    - Fix build against new libtool

  + ovitters <ovitters>
    - new version 2.24.14

* Wed Oct 31 2012 fwang <fwang> 2.24.13-2.mga3
+ Revision: 311704
- cleanup spec
- lock libmajor
- suggests oxygen instead of ia_ora
- drop last ia_ora reference

* Sun Sep 23 2012 ovitters <ovitters> 2.24.13-1.mga3
+ Revision: 296937
- new version 2.24.13

* Wed Sep 05 2012 fwang <fwang> 2.24.12-1.mga3
+ Revision: 288379
- tooltip related feature accepted by upstream in anoth bugreport (gnome bug#683070)
- new version 2.24.12

* Sun Jul 15 2012 ovitters <ovitters> 2.24.11-1.mga3
+ Revision: 271124
- new version 2.24.11

* Thu Apr 05 2012 tv <tv> 2.24.10-4.mga2
+ Revision: 228754
- require recent enough versions of libx11 & libxi so that live upgrade works
  after priority upgrade (mga#5168)
  (priority updates upgrades perl, thus perl-Gtk2, thus gtk+-2.x)

  + fwang <fwang>
    - drop unused part

* Fri Feb 10 2012 tv <tv> 2.24.10-3.mga2
+ Revision: 206893
- suggests oxygen them again now that metacity crash is fixed (mga#4408)
  (replaced the Requires tag by a Suggests one btw)

* Thu Feb 09 2012 tv <tv> 2.24.10-2.mga2
+ Revision: 206608
- do not pull oxygen them (too buggy)

* Mon Feb 06 2012 fwang <fwang> 2.24.10-1.mga2
+ Revision: 205457
- new version 2.24.10

* Wed Jan 25 2012 fwang <fwang> 2.24.9-1.mga2
+ Revision: 200717
- fix linkage against gmodule
- new version 2.24.9

  + tv <tv>
    - requires glib2.0-common instead of in basesystem

* Sun Dec 04 2011 obgr_seneca <obgr_seneca> 2.24.8-3.mga2
+ Revision: 176163
- fixed iconview bug causing lxappearance crashes
- patch fron upstream

* Sun Nov 13 2011 dmorgan <dmorgan> 2.24.8-2.mga2
+ Revision: 167299
- Move suggests as requires as it does not work well w/o

* Fri Nov 11 2011 wally <wally> 2.24.8-1.mga2
+ Revision: 166689
- new version 2.24.8
- rediff P12

* Mon Oct 24 2011 fwang <fwang> 2.24.7-2.mga2
+ Revision: 157593
- bump rel for rebuilding

* Sun Oct 23 2011 wally <wally> 2.24.7-1.mga2
+ Revision: 157493
- new version 2.24.7
- rediff P20

* Sat Sep 10 2011 fwang <fwang> 2.24.6-2.mga2
+ Revision: 142171
- rebuild for new libpng

* Wed Aug 31 2011 fwang <fwang> 2.24.6-1.mga2
+ Revision: 137179
- new version 2.24.6

* Mon Jul 11 2011 wally <wally> 2.24.5-6.mga2
+ Revision: 122408
- fix gir package requires (require libs)

* Sat Jul 09 2011 wally <wally> 2.24.5-5.mga2
+ Revision: 121215
- fix gir package name

  + dmorgan <dmorgan>
    - Remove wrong conflicts/requires

* Thu Jul 07 2011 dmorgan <dmorgan> 2.24.5-4.mga2
+ Revision: 119810
- Fix file list
- Split gir files outside lib package
- Sync spec file with gtk3

* Thu Jul 07 2011 fwang <fwang> 2.24.5-3.mga2
+ Revision: 119570
- rebuild for typelib rpm provides

* Tue Jul 05 2011 dmorgan <dmorgan> 2.24.5-2.mga2
+ Revision: 118944
- Fix default theme ( for coherency with gnome3 theme)

* Mon Jun 20 2011 fwang <fwang> 2.24.5-1.mga2
+ Revision: 110239
- new version 2.24.5

* Mon Jun 13 2011 ahmad <ahmad> 2.24.4-3.mga2
+ Revision: 105586
- Ship libgailutil.la for now, some builds (e.g. claws-mail-plugins) fail without it

* Thu Jun 09 2011 dmorgan <dmorgan> 2.24.4-2.mga2
+ Revision: 102524
- Do not package libgailutil.la

* Thu Apr 14 2011 tv <tv> 2.24.4-1.mga1
+ Revision: 85366
- new release

* Sun Mar 27 2011 ahmad <ahmad> 2.24.3-2.mga1
+ Revision: 77894
- add BR shared-mime-info so that the demos don't fail to build
- update to 2.24.3
- bump req_glib_version
- replace X11-devel with the required -devel packages
- move the libatk1.0 requires to the x11 subpackage (fwang)

* Mon Feb 14 2011 dmorgan <dmorgan> 2.22.1-2.mga1
+ Revision: 51705
- Fix file list
- Disable bootstrap
- Remove old conflicts

  + ahmad <ahmad>
    - add a comment about the need to toggle enable_gtkdoc to 1 when disabling the
      bootstrap, otherwise the build fails as autoreconf -fi exits with 1
    - when disabling the bootstrap, re-enable gtkdoc so that autoreconf -fi doesn't
      exit with 1

* Wed Jan 12 2011 dmorgan <dmorgan> 2.22.1-1.mga1
+ Revision: 7731
- Fix file list
- Disable autoreconf like told in comment
- Disable patch13 like told in comment
- imported package gtk+2.0

  + ahmad <ahmad>
    - drop old/unneeded scriptlets, and old conflicts
    - imported package gtk+2.0

